==> nhc98_1.16.orig.tar.gz: nhc98-1.16/src/prelude/Time/GetClockTime.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_Time_46hs_95getClockTime_35	((void*)startLabel+8)
#define CT_v187	((void*)startLabel+32)
#define F0_Time_46hs_95getClockTime_35	((void*)startLabel+40)
#define FN_Time_46hs_95getClockTime	((void*)startLabel+68)
#define CT_v191	((void*)startLabel+120)
#define CF_Time_46hs_95getClockTime	((void*)startLabel+128)
#define CT_v196	((void*)startLabel+240)
#define FN_LAMBDA183	((void*)startLabel+288)
#define CT_v201	((void*)startLabel+388)
#define F0_LAMBDA183	((void*)startLabel+396)
#define ST_v193	((void*)startLabel+420)
#define PP_LAMBDA183	((void*)startLabel+438)
#define PC_LAMBDA183	((void*)startLabel+438)
#define ST_v198	((void*)startLabel+438)
#define PP_Time_46hs_95getClockTime	((void*)startLabel+462)
#define PC_Time_46hs_95getClockTime	((void*)startLabel+462)
#define ST_v189	((void*)startLabel+462)
#define PP_Time_46hs_95getClockTime_35	((void*)startLabel+483)
#define PC_Time_46hs_95getClockTime_35	((void*)startLabel+483)
#define ST_v186	((void*)startLabel+483)
#define PS_v190	((void*)startLabel+508)
#define PS_v188	((void*)startLabel+520)
#define PS_v192	((void*)startLabel+532)
#define PS_v195	((void*)startLabel+544)
#define PS_v194	((void*)startLabel+556)
#define PS_v185	((void*)startLabel+568)
#define PS_v199	((void*)startLabel+580)
#define PS_v200	((void*)startLabel+592)
#define PS_v197	((void*)startLabel+604)
void FR_Time_46hs_95getClockTime_35(void);
extern Node FN_NHC_46Internal_46_95mkIOok0[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46return[];
extern Node PM_Time[];
extern Node PC_NHC_46Internal_46_95mkIOok0[];
extern Node PM_Time[];
extern Node PM_Time[];
extern Node PM_Time[];
extern Node PC_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node PM_Time[];
extern Node PM_Time[];
extern Node PM_Time[];
extern Node PC_Time_46CT[];
extern Node PM_Time[];
extern Node PC_Prelude_46Monad_46NHC_46Internal_46IO_46return[];
extern Node PM_Time[];

static Node startLabel[] = {
  bytes2word(1,0,0,1)
, useLabel(CT_v187)
,	/* FN_Time_46hs_95getClockTime_35: (byte 0) */
  bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
, useLabel(FR_Time_46hs_95getClockTime_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 90022
, useLabel(ST_v186)
,	/* CT_v187: (byte 0) */
  HW(0,1)
, 0
,	/* F0_Time_46hs_95getClockTime_35: (byte 0) */
  CAPTAG(useLabel(FN_Time_46hs_95getClockTime_35),1)
, useLabel(PS_v185)
, 0
, 0
, 0
, bytes2word(0,0,0,0)
, useLabel(CT_v191)
,	/* FN_Time_46hs_95getClockTime: (byte 0) */
  bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_CVAL_P1,8,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v190)
, 0
, 0
, 0
, 0
, 90022
, useLabel(ST_v189)
,	/* CT_v191: (byte 0) */
  HW(2,0)
, 0
,	/* CF_Time_46hs_95getClockTime: (byte 0) */
  VAPTAG(useLabel(FN_Time_46hs_95getClockTime))
, useLabel(PS_v188)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok0))
, useLabel(F0_Time_46hs_95getClockTime_35)
, bytes2word(0,0,0,0)
, useLabel(CT_v196)
,};
Node FN_Time_46getClockTime[] = {
  bytes2word(NEEDHEAP_I32,HEAP_CVAL_P1,7,HEAP_CVAL_N1)
, bytes2word(7,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,8,HEAP_CVAL_N1)
, bytes2word(12,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_CVAL_P1,9,HEAP_OFF_N1,11)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, useLabel(PS_v195)
, 0
, 0
, 0
, 0
, useLabel(PS_v194)
, 0
, 0
, 0
, 0
, 120001
, useLabel(ST_v193)
,	/* CT_v196: (byte 0) */
  HW(3,0)
, 0
,};
Node CF_Time_46getClockTime[] = {
  VAPTAG(useLabel(FN_Time_46getClockTime))
, useLabel(PS_v192)
, 0
, 0
, 0
, CAPTAG(useLabel(FN_LAMBDA183),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61))
, useLabel(CF_Time_46hs_95getClockTime)
, bytes2word(1,0,0,1)
, useLabel(CT_v201)
,	/* FN_LAMBDA183: (byte 0) */
  bytes2word(NEEDHEAP_I32,HEAP_CVAL_N1,7,HEAP_CVAL_N1)
, bytes2word(12,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_ARG,1,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(7,HEAP_CVAL_N1,17,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,11)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v200)
, 0
, 0
, 0
, 0
, useLabel(PS_v199)
, 0
, 0
, 0
, 0
, CONSTR(0,1,0)
, 0
, 0
, 0
, 0
, 130011
, useLabel(ST_v198)
,	/* CT_v201: (byte 0) */
  HW(1,1)
, 0
,	/* F0_LAMBDA183: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA183),1)
, useLabel(PS_v197)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46return))
,};
Node PP_Time_46getClockTime[] = {
 };
Node PC_Time_46getClockTime[] = {
 	/* ST_v193: (byte 0) */
  bytes2word(84,105,109,101)
, bytes2word(46,103,101,116)
, bytes2word(67,108,111,99)
, bytes2word(107,84,105,109)
,	/* PP_LAMBDA183: (byte 2) */
 	/* PC_LAMBDA183: (byte 2) */
 	/* ST_v198: (byte 2) */
  bytes2word(101,0,84,105)
, bytes2word(109,101,46,103)
, bytes2word(101,116,67,108)
, bytes2word(111,99,107,84)
, bytes2word(105,109,101,58)
, bytes2word(49,51,58,49)
,	/* PP_Time_46hs_95getClockTime: (byte 2) */
 	/* PC_Time_46hs_95getClockTime: (byte 2) */
 	/* ST_v189: (byte 2) */
  bytes2word(49,0,84,105)
, bytes2word(109,101,46,104)
, bytes2word(115,95,103,101)
, bytes2word(116,67,108,111)
, bytes2word(99,107,84,105)
,	/* PP_Time_46hs_95getClockTime_35: (byte 3) */
 	/* PC_Time_46hs_95getClockTime_35: (byte 3) */
 	/* ST_v186: (byte 3) */
  bytes2word(109,101,0,84)
, bytes2word(105,109,101,46)
, bytes2word(104,115,95,103)
, bytes2word(101,116,67,108)
, bytes2word(111,99,107,84)
, bytes2word(105,109,101,35)
, bytes2word(0,0,0,0)
,	/* PS_v190: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46hs_95getClockTime)
, useLabel(PC_NHC_46Internal_46_95mkIOok0)
,	/* PS_v188: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46hs_95getClockTime)
, useLabel(PC_Time_46hs_95getClockTime)
,	/* PS_v192: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46getClockTime)
, useLabel(PC_Time_46getClockTime)
,	/* PS_v195: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46getClockTime)
, useLabel(PC_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61)
,	/* PS_v194: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46getClockTime)
, useLabel(PC_LAMBDA183)
,	/* PS_v185: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46hs_95getClockTime_35)
, useLabel(PC_Time_46hs_95getClockTime_35)
,	/* PS_v199: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_LAMBDA183)
, useLabel(PC_Time_46CT)
,	/* PS_v200: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_LAMBDA183)
, useLabel(PC_Prelude_46Monad_46NHC_46Internal_46IO_46return)
,	/* PS_v197: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_LAMBDA183)
, useLabel(PC_LAMBDA183)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_getClockTime" Time.hs_getClockTime# 1 :: Prelude.() -> Prelude.Int */
extern HsInt hs_getClockTime(void);
#ifdef PROFILE
static SInfo pf_hs_getClockTime = {"Time","Time.hs_getClockTime#","Prelude.Int"};
#endif
C_HEADER(FR_Time_46hs_95getClockTime_35) {
  NodePtr nodeptr;
  HsInt result;
  /* void arg1 */;

  result = hs_getClockTime();

  nodeptr = nhc_mkInt(result);
  INIT_PROFINFO(nodeptr,&pf_hs_getClockTime);
  C_RETURN(nodeptr);
}

==> nhc98_1.18.orig.tar.gz: nhc98-1.18/src/prelude/Time/GetClockTime.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_Time_46hs_95getClockTime_35	((void*)startLabel+8)
#define CT_v191	((void*)startLabel+32)
#define F0_Time_46hs_95getClockTime_35	((void*)startLabel+40)
#define FN_Time_46hs_95getClockTime	((void*)startLabel+68)
#define CT_v195	((void*)startLabel+120)
#define CF_Time_46hs_95getClockTime	((void*)startLabel+128)
#define CT_v200	((void*)startLabel+240)
#define FN_LAMBDA187	((void*)startLabel+288)
#define CT_v205	((void*)startLabel+388)
#define F0_LAMBDA187	((void*)startLabel+396)
#define ST_v197	((void*)startLabel+420)
#define PP_LAMBDA187	((void*)startLabel+438)
#define PC_LAMBDA187	((void*)startLabel+438)
#define ST_v202	((void*)startLabel+438)
#define PP_Time_46hs_95getClockTime	((void*)startLabel+468)
#define PC_Time_46hs_95getClockTime	((void*)startLabel+468)
#define ST_v193	((void*)startLabel+468)
#define PP_Time_46hs_95getClockTime_35	((void*)startLabel+489)
#define PC_Time_46hs_95getClockTime_35	((void*)startLabel+489)
#define ST_v190	((void*)startLabel+489)
#define PS_v194	((void*)startLabel+512)
#define PS_v192	((void*)startLabel+524)
#define PS_v196	((void*)startLabel+536)
#define PS_v199	((void*)startLabel+548)
#define PS_v198	((void*)startLabel+560)
#define PS_v189	((void*)startLabel+572)
#define PS_v203	((void*)startLabel+584)
#define PS_v204	((void*)startLabel+596)
#define PS_v201	((void*)startLabel+608)
void FR_Time_46hs_95getClockTime_35(void);
extern Node FN_NHC_46Internal_46_95mkIOok0[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46return[];
extern Node PM_Time[];
extern Node PC_NHC_46Internal_46_95mkIOok0[];
extern Node PC_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node PC_Time_46CT[];
extern Node PC_Prelude_46Monad_46NHC_46Internal_46IO_46return[];

static Node startLabel[] = {
  bytes2word(1,0,0,1)
, useLabel(CT_v191)
,	/* FN_Time_46hs_95getClockTime_35: (byte 0) */
  bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
, useLabel(FR_Time_46hs_95getClockTime_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 90001
, useLabel(ST_v190)
,	/* CT_v191: (byte 0) */
  HW(0,1)
, 0
,	/* F0_Time_46hs_95getClockTime_35: (byte 0) */
  CAPTAG(useLabel(FN_Time_46hs_95getClockTime_35),1)
, useLabel(PS_v189)
, 0
, 0
, 0
, bytes2word(0,0,0,0)
, useLabel(CT_v195)
,	/* FN_Time_46hs_95getClockTime: (byte 0) */
  bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_CVAL_P1,8,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v194)
, 0
, 0
, 0
, 0
, 90001
, useLabel(ST_v193)
,	/* CT_v195: (byte 0) */
  HW(2,0)
, 0
,	/* CF_Time_46hs_95getClockTime: (byte 0) */
  VAPTAG(useLabel(FN_Time_46hs_95getClockTime))
, useLabel(PS_v192)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok0))
, useLabel(F0_Time_46hs_95getClockTime_35)
, bytes2word(0,0,0,0)
, useLabel(CT_v200)
,};
Node FN_Time_46getClockTime[] = {
  bytes2word(NEEDHEAP_I32,HEAP_CVAL_P1,7,HEAP_CVAL_N1)
, bytes2word(7,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,8,HEAP_CVAL_N1)
, bytes2word(12,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_CVAL_P1,9,HEAP_OFF_N1,11)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, useLabel(PS_v199)
, 0
, 0
, 0
, 0
, useLabel(PS_v198)
, 0
, 0
, 0
, 0
, 120001
, useLabel(ST_v197)
,	/* CT_v200: (byte 0) */
  HW(3,0)
, 0
,};
Node CF_Time_46getClockTime[] = {
  VAPTAG(useLabel(FN_Time_46getClockTime))
, useLabel(PS_v196)
, 0
, 0
, 0
, CAPTAG(useLabel(FN_LAMBDA187),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61))
, useLabel(CF_Time_46hs_95getClockTime)
, bytes2word(1,0,0,1)
, useLabel(CT_v205)
,	/* FN_LAMBDA187: (byte 0) */
  bytes2word(NEEDHEAP_I32,HEAP_CVAL_N1,7,HEAP_CVAL_N1)
, bytes2word(12,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_ARG,1,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(7,HEAP_CVAL_N1,17,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,11)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v204)
, 0
, 0
, 0
, 0
, useLabel(PS_v203)
, 0
, 0
, 0
, 0
, CONSTR(0,1,0)
, 0
, 0
, 0
, 0
, 130011
, useLabel(ST_v202)
,	/* CT_v205: (byte 0) */
  HW(1,1)
, 0
,	/* F0_LAMBDA187: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA187),1)
, useLabel(PS_v201)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46return))
,};
Node PP_Time_46getClockTime[] = {
 };
Node PC_Time_46getClockTime[] = {
 	/* ST_v197: (byte 0) */
  bytes2word(84,105,109,101)
, bytes2word(46,103,101,116)
, bytes2word(67,108,111,99)
, bytes2word(107,84,105,109)
,	/* PP_LAMBDA187: (byte 2) */
 	/* PC_LAMBDA187: (byte 2) */
 	/* ST_v202: (byte 2) */
  bytes2word(101,0,84,105)
, bytes2word(109,101,46,103)
, bytes2word(101,116,67,108)
, bytes2word(111,99,107,84)
, bytes2word(105,109,101,58)
, bytes2word(49,51,58,49)
, bytes2word(49,45,49,51)
,	/* PP_Time_46hs_95getClockTime: (byte 4) */
 	/* PC_Time_46hs_95getClockTime: (byte 4) */
 	/* ST_v193: (byte 4) */
  bytes2word(58,50,53,0)
, bytes2word(84,105,109,101)
, bytes2word(46,104,115,95)
, bytes2word(103,101,116,67)
, bytes2word(108,111,99,107)
, bytes2word(84,105,109,101)
,	/* PP_Time_46hs_95getClockTime_35: (byte 1) */
 	/* PC_Time_46hs_95getClockTime_35: (byte 1) */
 	/* ST_v190: (byte 1) */
  bytes2word(0,84,105,109)
, bytes2word(101,46,104,115)
, bytes2word(95,103,101,116)
, bytes2word(67,108,111,99)
, bytes2word(107,84,105,109)
, bytes2word(101,35,0,0)
,	/* PS_v194: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46hs_95getClockTime)
, useLabel(PC_NHC_46Internal_46_95mkIOok0)
,	/* PS_v192: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46hs_95getClockTime)
, useLabel(PC_Time_46hs_95getClockTime)
,	/* PS_v196: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46getClockTime)
, useLabel(PC_Time_46getClockTime)
,	/* PS_v199: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46getClockTime)
, useLabel(PC_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61)
,	/* PS_v198: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46getClockTime)
, useLabel(PC_LAMBDA187)
,	/* PS_v189: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46hs_95getClockTime_35)
, useLabel(PC_Time_46hs_95getClockTime_35)
,	/* PS_v203: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_LAMBDA187)
, useLabel(PC_Time_46CT)
,	/* PS_v204: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_LAMBDA187)
, useLabel(PC_Prelude_46Monad_46NHC_46Internal_46IO_46return)
,	/* PS_v201: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_LAMBDA187)
, useLabel(PC_LAMBDA187)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_getClockTime" Time.hs_getClockTime# 1 :: Prelude.() -> Prelude.Int */
extern HsInt hs_getClockTime(void);
#ifdef PROFILE
static SInfo pf_Time_46hs_95getClockTime_35 = {"Time","Time.hs_getClockTime#","Prelude.Int"};
#endif
C_HEADER(FR_Time_46hs_95getClockTime_35) {
  NodePtr nodeptr;
  HsInt result;
  /* void arg1 */;

  result = hs_getClockTime();

  nodeptr = nhc_mkInt(result);
  INIT_PROFINFO(nodeptr,&pf_Time_46hs_95getClockTime_35);
  C_RETURN(nodeptr);
}
